/*缩略图片样式*/
.selected-img {
    width: 160px;
    height: 100px;
    position: relative;
    display: inline-block;
    overflow: hidden;
    border: solid #b1c6c1 1px;
    border-radius: 10px;
    margin-right: 10px;
}

/*缩略图片聚焦样式*/
.selected-img:hover {
    cursor: pointer;
}

/*上传图片按钮样式*/
.file-button {
    width: 160px;
    height: 100px;
    position: relative;
    display: inline-block;
    overflow: hidden;
    border: solid #b1c6c1 1px;
    border-radius: 10px;
    margin-right: 10px;
    background-repeat: no-repeat;
    background-size: 64px;
    background-position: center
}

/*上传图片按钮聚焦样式*/
.file-button:hover {
    cursor: pointer;
}

.file-button input {
    position: absolute;
    top: 0;
    height: 100px;
    opacity: 0;
}

/*删除缩略图片icon聚焦样式*/
i:hover {
    color: #0081C6;
}

.cover_image {
    width: 160px;
    height: 100px;
    border-radius: 10px;
}

.delete_icon_image {
    z-index: 999;
    background-color: rgba(255, 255, 255, .8);
    position: absolute;
    right: 3px;
    top: 3px;
}

/*阿里云字体图标*/
@font-face {
    font-family: 'iconfont';  /* project id 1361777 */
    src: url('//at.alicdn.com/t/font_1361777_ufufbwqmfpa.eot');
    src: url('//at.alicdn.com/t/font_1361777_ufufbwqmfpa.eot?#iefix') format('embedded-opentype'),
    url('//at.alicdn.com/t/font_1361777_ufufbwqmfpa.woff2') format('woff2'),
    url('//at.alicdn.com/t/font_1361777_ufufbwqmfpa.woff') format('woff'),
    url('//at.alicdn.com/t/font_1361777_ufufbwqmfpa.ttf') format('truetype'),
    url('//at.alicdn.com/t/font_1361777_ufufbwqmfpa.svg#iconfont') format('svg');
}

.iconfont {
    font-family: "iconfont" !important;
    font-size: 20px;
    font-style: normal;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

.icon-delete:before {
    content: "\e63c";
}

.big-img-box {
    position: fixed;
    top: 0;
    left: 0;
    background: rgba(0, 0, 0, 0.7);
    z-index: 10000;
    width: 100%;
    height: 100%;
    display: none;
}

#bigimg {
    border: 5px solid #fff;
}
